@@ -21,7 +21,7 @@ Usage::
     list_builds_for_project_paginator: ListBuildsForProjectPaginator = client.get_paginator("list_builds_for_project")
     list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
 """
-from mypy_boto3_codebuild.client import CodeBuildClient as Client, CodeBuildClient
+from mypy_boto3_codebuild.client import CodeBuildClient, CodeBuildClient as Client
 from mypy_boto3_codebuild.paginator import (
     ListBuildsForProjectPaginator,
     ListBuildsPaginator,
