@@ -1,6 +1,12 @@
-"Main interface for codebuild service type defs"
-from __future__ import annotations
+"""
+Main interface for codebuild service type definitions.
 
+Usage::
+
+    from mypy_boto3.codebuild.type_defs import BuildNotDeletedTypeDef
+
+    data: BuildNotDeletedTypeDef = {...}
+"""
 from datetime import datetime
 import sys
 from typing import Dict, List
@@ -15,6 +21,77 @@ else:
     from typing_extensions import TypedDict
 
 
+__all__ = (
+    "BuildNotDeletedTypeDef",
+    "BatchDeleteBuildsOutputTypeDef",
+    "BuildArtifactsTypeDef",
+    "PhaseContextTypeDef",
+    "BuildPhaseTypeDef",
+    "ExportedEnvironmentVariableTypeDef",
+    "CloudWatchLogsConfigTypeDef",
+    "S3LogsConfigTypeDef",
+    "LogsLocationTypeDef",
+    "NetworkInterfaceTypeDef",
+    "ProjectCacheTypeDef",
+    "EnvironmentVariableTypeDef",
+    "RegistryCredentialTypeDef",
+    "ProjectEnvironmentTypeDef",
+    "ProjectFileSystemLocationTypeDef",
+    "GitSubmodulesConfigTypeDef",
+    "SourceAuthTypeDef",
+    "ProjectSourceTypeDef",
+    "ProjectSourceVersionTypeDef",
+    "VpcConfigTypeDef",
+    "BuildTypeDef",
+    "BatchGetBuildsOutputTypeDef",
+    "LogsConfigTypeDef",
+    "ProjectArtifactsTypeDef",
+    "ProjectBadgeTypeDef",
+    "TagTypeDef",
+    "WebhookFilterTypeDef",
+    "WebhookTypeDef",
+    "ProjectTypeDef",
+    "BatchGetProjectsOutputTypeDef",
+    "S3ReportExportConfigTypeDef",
+    "ReportExportConfigTypeDef",
+    "ReportGroupTypeDef",
+    "BatchGetReportGroupsOutputTypeDef",
+    "TestReportSummaryTypeDef",
+    "ReportTypeDef",
+    "BatchGetReportsOutputTypeDef",
+    "CreateProjectOutputTypeDef",
+    "CreateReportGroupOutputTypeDef",
+    "CreateWebhookOutputTypeDef",
+    "DeleteSourceCredentialsOutputTypeDef",
+    "TestCaseTypeDef",
+    "DescribeTestCasesOutputTypeDef",
+    "GetResourcePolicyOutputTypeDef",
+    "ImportSourceCredentialsOutputTypeDef",
+    "ListBuildsForProjectOutputTypeDef",
+    "ListBuildsOutputTypeDef",
+    "EnvironmentImageTypeDef",
+    "EnvironmentLanguageTypeDef",
+    "EnvironmentPlatformTypeDef",
+    "ListCuratedEnvironmentImagesOutputTypeDef",
+    "ListProjectsOutputTypeDef",
+    "ListReportGroupsOutputTypeDef",
+    "ListReportsForReportGroupOutputTypeDef",
+    "ListReportsOutputTypeDef",
+    "ListSharedProjectsOutputTypeDef",
+    "ListSharedReportGroupsOutputTypeDef",
+    "SourceCredentialsInfoTypeDef",
+    "ListSourceCredentialsOutputTypeDef",
+    "PaginatorConfigTypeDef",
+    "PutResourcePolicyOutputTypeDef",
+    "ReportFilterTypeDef",
+    "StartBuildOutputTypeDef",
+    "StopBuildOutputTypeDef",
+    "TestCaseFilterTypeDef",
+    "UpdateProjectOutputTypeDef",
+    "UpdateReportGroupOutputTypeDef",
+    "UpdateWebhookOutputTypeDef",
+)
+
 BuildNotDeletedTypeDef = TypedDict(
     "BuildNotDeletedTypeDef", {"id": str, "statusCode": str}, total=False
 )
@@ -192,6 +269,18 @@ class ProjectEnvironmentTypeDef(
     pass
 
 
+ProjectFileSystemLocationTypeDef = TypedDict(
+    "ProjectFileSystemLocationTypeDef",
+    {
+        "type": Literal["EFS"],
+        "location": str,
+        "mountPoint": str,
+        "identifier": str,
+        "mountOptions": str,
+    },
+    total=False,
+)
+
 GitSubmodulesConfigTypeDef = TypedDict("GitSubmodulesConfigTypeDef", {"fetchSubmodules": bool})
 
 _RequiredSourceAuthTypeDef = TypedDict("_RequiredSourceAuthTypeDef", {"type": Literal["OAUTH"]})
@@ -280,6 +369,7 @@ BuildTypeDef = TypedDict(
         "encryptionKey": str,
         "exportedEnvironmentVariables": List[ExportedEnvironmentVariableTypeDef],
         "reportArns": List[str],
+        "fileSystemLocations": List[ProjectFileSystemLocationTypeDef],
     },
     total=False,
 )
@@ -379,6 +469,7 @@ ProjectTypeDef = TypedDict(
         "vpcConfig": VpcConfigTypeDef,
         "badge": ProjectBadgeTypeDef,
         "logsConfig": LogsConfigTypeDef,
+        "fileSystemLocations": List[ProjectFileSystemLocationTypeDef],
     },
     total=False,
 )
